==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudbroker/image/resource_image/main.tf <==
/*
Пример использования
Ресурса image
Ресурс позволяет:
1. Создавать образ
2. Редактировать образ
3. Удалять образ
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_cb_image" "my_image" {
  #имя образа
  #обязательный параметр
  #тип - строка
  #при изменении - изменяет название созданного образа
  name = "test_image_rename"

  #адрес образа
  #опциональный параметр
  #внимание, для создания ресурса обязательно должен быть указан или url, или image_file
  #тип - строка
  url = "https://colba.decs.online/index.php/s/G3H7AREngzeKGw2/download"

  #путь к образу для загрузки
  #опциональный параметр
  #внимание, для создания ресурса обязательно должен быть указан или url, или image_file
  #тип - строка
  file_path = "img.iso"

  #grid id образа
  #обязательный параметр
  #тип - целое число
  gid = 212

  #тип загрузки образа
  #обязательный параметр
  #тип - строка
  #возможные варианты: "bios" или "uefi"
  boot_type = "bios"

  #тип образа
  #обязательный параметр
  #тип - строка
  #возможные варианты - "linux", "windows"
  image_type = "linux"

  #драйвера
  #обязательный параметр
  #тип - массив строк
  #возможные варианты - ["KVM_X86", "SVA_KVM_X86"], ["KVM_X86"], ["SVA_KVM_X86"]
  drivers = ["KVM_X86", "SVA_KVM_X86"]

  #поддержка hot resize
  #опциональный параметр
  #тип - булев
  #hot_resize = true

  #id аккаунта владельца образа
  #опциональный параметр
  #может быть использован как при создании,
  #так и при редактировании образа
  #тип данных - целое число
  #account_id = 57252

  #имя пользователя и пароль 
  #опциональные параметры, 
  #могут быть использованы как при создании образа,
  #так и при его редактировании
  #тип - строка
  #username = "Valera"
  #password = "123"

  #имя пользователя и пароль для загрузки бинарных данных
  #опциональные параметры, 
  #могут быть использованы как при создании образа,
  #так и при его редактировании
  #тип - строка
  #username_dl = "Valera1"
  #password_dl = "1231"

  #sep id
  #опциональный параметр, используется при создании
  #тип - целое число
  #sep_id       = 1206

  #пул для создания образа
  #опциональный тип, используется при создании образа
  #тип - строка
  #pool_name    = "vmstor"

  #архитектура системы образа
  #опциональный параметр, используется при создании
  #тип - строка
  #доступные значения: "X86_64"
  #architecture = "X86_64"

  #доступность образа
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - булев
  #enabled = true

  #является ли образ загрузочным 
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - булев
  #bootable = true

  #позволяет создавать образ в синхронном режиме
  #опциональный параметр
  #тип - булев
  #sync_mode = true

  #настройка доступа образа аккаунтам
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - массив целых чисел
  #пустой массив - удаление всех доступов, если они были
  #shared_with = [28096, 57121]

  #установка computeci
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - целое число
  #чтобы сбросить, необходимо передать 0
  #computeci_id = 1

  #доступные стаки
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - массив целых чисел
  #для удаления всех доступных стаков, необходимо передать пустой массив
  #enabled_stacks = [9]

  #аккаунты, которым предоставляется доступ к образу
  #опциональный параметр
  #тип - массив целых чисел
  #для удаления всех доступных аккаунтов, необходимо передать пустой массив
  #accounts = [9, 5]

  #наименование сетевого интерфейса для вашего компьютера с Linux, eth - встроенный, ens - pci слот
  #опциональный параметр
  #тип - строка
  #network_interface_naming = "ens"
}

output "test" {
  value = decort_cb_image.my_image
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudbroker/image/resource_image/main.tf <==
/*
Пример использования
Ресурса image
Ресурс позволяет:
1. Создавать образ
2. Редактировать образ
3. Удалять образ
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator        = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url       = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_cb_image" "my_image" {
  #имя образа
  #обязательный параметр
  #тип - строка
  #используется при создании и обновлении
  name = "test_image_rename"

  #адрес образа
  #опциональный параметр
  #внимание, для создания ресурса обязательно должен быть указан или url, или file_path
  #тип - строка
  #используется при создании
  url = "https://colba.decs.online/index.php/s/G3H7AREngzeKGw2/download"

  #путь к образу для загрузки
  #опциональный параметр
  #внимание, для создания ресурса обязательно должен быть указан или url, или file_path
  #тип - строка
  #используется при создании
  file_path = "img.iso"

  #тип загрузки образа
  #обязательный параметр
  #тип - строка
  #возможные варианты: "bios" или "uefi"
  #используется при создании
  boot_type = "bios"

  #тип образа
  #обязательный параметр
  #тип - строка
  #возможные варианты - "linux", "windows", "unknown"
  #используется при создании
  image_type = "linux"

  #драйвера
  #обязательный параметр
  #тип - массив строк
  #возможные варианты - ["KVM_X86", "SVA_KVM_X86"], ["KVM_X86"], ["SVA_KVM_X86"]
  #используется при создании
  drivers = ["KVM_X86", "SVA_KVM_X86"]

  #поддержка hot resize
  #опциональный параметр
  #тип - булев
  #используется при создании и обновлении
  #hot_resize = true

  #id аккаунта владельца образа
  #опциональный параметр
  #тип данных - целое число
  #используется при создании и обновлении
  #account_id = 57252

  #имя пользователя и пароль 
  #опциональные параметры
  #тип - строка
  #используется при создании и обновлении
  #username = "Valera"
  #password = "123"

  #имя пользователя и пароль для загрузки бинарных данных
  #опциональные параметры
  #тип - строка
  #используется при создании
  #username_dl = "Valera1"
  #password_dl = "1231"

  #sep id
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #sep_id = 1206

  #пул для создания образа
  #опциональный параметр
  #тип - строка
  #используется при создании
  #pool_name = "vmstor"

  #архитектура системы образа
  #опциональный параметр
  #тип - строка
  #доступные значения: "X86_64"
  #используется при создании
  #architecture = "X86_64"

  #доступность образа
  #опциональный параметр
  #тип - булев
  #используется при создании и обновлении
  #enabled = true

  #является ли образ загрузочным 
  #опциональный параметр
  #тип - булев
  #используется при создании и обновлении
  #bootable = true

  #позволяет создавать образ в синхронном режиме
  #опциональный параметр
  #тип - булев
  #используется при создании
  #sync_mode = true

  #настройка доступа образа аккаунтам
  #опциональный параметр
  #тип - массив целых чисел
  #пустой массив - удаление всех доступов, если они были
  #используется при обновлении
  #shared_with = [28096, 57121]

  #установка computeci
  #опциональный параметр
  #тип - целое число
  #чтобы сбросить, необходимо передать 0
  #используется при обновлении
  #computeci_id = 1

  #доступные стаки
  #опциональный параметр
  #тип - массив целых чисел
  #для удаления всех доступных стаков, необходимо передать пустой массив
  #используется при обновлении
  #enabled_stacks = [9]

  #аккаунты, которым предоставляется доступ к образу
  #опциональный параметр
  #тип - массив целых чисел
  #для удаления всех доступных аккаунтов, необходимо передать пустой массив
  #используется при обновлении
  #accounts = [9, 5]

  #наименование сетевого интерфейса для вашего компьютера с Linux
  #eth - встроенный, ens - pci слот
  #опциональный параметр
  #тип - строка
  #используется при создании и обновлении
  #network_interface_naming = "ens"
}

output "test" {
  value = decort_cb_image.my_image
}
